@@ -81,6 +81,11 @@ var configByHost = map[string]oauth2.Config{
 		ClientID: "6e1363d5730bd1068bc908d6eda9f4f7e72352147dbe15f441a2f9e2ce5aebee",
 		Endpoint: replaceHost(endpoints.GitLab, "gitlab.alpinelinux.org"),
 		Scopes:   []string{"read_repository", "write_repository"}},
+	// https://hifis.net/doc/software/gitlab/getting-started/#use-git-credential-oauth
+	"codebase.helmholtz.cloud": {
+		ClientID: "e79ac88d46e4f3f79a494166fabb0310e7879d8e4776f316fb57b3100eaec13a",
+		Endpoint: replaceHost(endpoints.GitLab, "codebase.helmholtz.cloud"),
+		Scopes:   []string{"read_repository", "write_repository"}},
 	// https://gitea.com/user/settings/applications/oauth2/218
 	"invent.kde.org": {
 		ClientID: "36ee2eeb4f179b38db8f066fd4ca9751f4b003653a205fc1422f110ca60181f6",
@@ -310,23 +315,16 @@ func main() {
 		if verbose {
 			fmt.Fprintln(os.Stderr, "token:", token)
 		}
-		var username string
-		if host == "bitbucket.org" {
-			// https://support.atlassian.com/bitbucket-cloud/docs/use-oauth-on-bitbucket-cloud/#Cloning-a-repository-with-an-access-token
-			username = "x-token-auth"
-		} else if looksLikeGitLab {
-			// https://docs.gitlab.com/ee/api/oauth2.html#access-git-over-https-with-access-token
-			username = "oauth2"
-		} else if pairs["username"] == "" {
-			username = "oauth2"
-		}
 		output := map[string]string{
 			"password": token.AccessToken,
 		}
-		if username != "" {
-			output["username"] = username
-			if pairs["username"] != "" && pairs["username"] != username {
-				fmt.Fprintf(os.Stderr, "Username '%s' is incompatible with OAuth. This frustrates retrieval of stored OAuth credentials. Please remove username from remote URL and unset config key credential.username.\n.", pairs["username"])
+		if pairs["username"] == "" {
+			if host == "bitbucket.org" {
+				// https://support.atlassian.com/bitbucket-cloud/docs/use-oauth-on-bitbucket-cloud/#Cloning-a-repository-with-an-access-token
+				output["username"] = "x-token-auth"
+			} else {
+				// https://docs.gitlab.com/ee/api/oauth2.html#access-git-over-https-with-access-token
+				output["username"] = "oauth2"
 			}
 		}
 		if !token.Expiry.IsZero() {
@@ -452,7 +450,7 @@ func getToken(ctx context.Context, c oauth2.Config, authURLSuffix string) (*oaut
 	if _, err := exec.LookPath(open); err == nil {
 		err = exec.Command(open, p...).Run()
 		if err != nil {
-			return nil, err
+			fmt.Fprintf(os.Stderr, "Unable to open browser using '%s': %s\n", open, err)
 		}
 	}
 	query := <-queries
